package org.apidesign.apifest08.currency;

/**
 * Convertor factory is a factory class for creating {@link Convertor Convertor}
 * instances.
 *
 * @author jindra
 */
public final class ConvertorFactory {

    // this class needs no instances
    private ConvertorFactory() {
    }


    /**
     * Create a {@link Convertor Convertor} with given exchange rate
     *
     * @param exchangeRate double reprezenting the exchange rate from primary currency into
     * the secundary currecny
     * @return {@link Convertor Convertor} instance with given exchange rate
     */
    public static Convertor createConvertor(double exchangeRate) {
        if (exchangeRate == 0) {
            throw new IllegalArgumentException("Zero exchange rate is not allowed.");
        }
        return new ConvertorImpl(exchangeRate);

    }
}
